summaryrefslogtreecommitdiffstats
path: root/firmware
diff options
context:
space:
mode:
authorNils Wallménius <nils@rockbox.org>2010-05-14 08:52:54 +0000
committerNils Wallménius <nils@rockbox.org>2010-05-14 08:52:54 +0000
commit92a6081531e9ff4ed7612eeaf18b20dc189e8754 (patch)
tree12e2c61b538ad500fe9464ff8ccbbe88798fd832 /firmware
parentd665c926528219cc01be33658e8897a1472db827 (diff)
downloadrockbox-92a6081531e9ff4ed7612eeaf18b20dc189e8754.tar.gz
rockbox-92a6081531e9ff4ed7612eeaf18b20dc189e8754.zip
Disable shutting down with the charger connected on the gigabeat s since it doesn't charge while powered off. Ideally we should implement a mode where it charges untill the battery is full and then powers off.
git-svn-id: svn://svn.rockbox.org/rockbox/trunk@26012 a1c6a512-1295-4272-9138-f99709370657
Diffstat (limited to 'firmware')
-rw-r--r--firmware/export/config/gigabeats.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/firmware/export/config/gigabeats.h b/firmware/export/config/gigabeats.h
index 19a8fa4bf8..2bc56ec98c 100644
--- a/firmware/export/config/gigabeats.h
+++ b/firmware/export/config/gigabeats.h
@@ -158,11 +158,13 @@
/* TODO: have a proper status displayed in the bootloader and have it
* work! */
/* Charing implemented in a target-specific algorithm */
#define CONFIG_CHARGING CHARGING_TARGET
/* define this if the hardware can be powered off while charging */
-#define HAVE_POWEROFF_WHILE_CHARGING
+/* We don't charge while powered down so maybe implement a
+ finish-charging-and-then-poweroff mode */
+//#define HAVE_POWEROFF_WHILE_CHARGING
/* The size of the flash ROM */
#define FLASH_SIZE 0x200000
@@ -158,11 +158,13 @@
/* TODO: have a proper status displayed in the bootloader and have it
* work! */
-/* Charing implemented in a target-specific algorithm */
+/* Charging implemented in a target-specific algorithm */
#define CONFIG_CHARGING CHARGING_TARGET
/* define this if the hardware can be powered off while charging */